PgPool

Struct PgPool 

pub struct PgPool {
    pub manager: PgConnectionManager,
    pub inner: Pool<PgConnectionManager>,
}

Fields

manager: PgConnectionManagerinner: Pool<PgConnectionManager>

Implementations

Source

impl PgPool

pub async fn get(&self) -> Result<PgConnection, Error<PgError>>

Returns a single connection by either opening a new connection or returning an existing connection from the connection pool. Conn will block until either a connection is returned or timeout.

pub async fn get_timeout( &self, duration: Duration, ) -> Result<PgConnection, Error<PgError>>

Retrieves a connection from the pool, waiting for at most timeout

The given timeout will be used instead of the configured connection timeout.